==> haskell-cborg-json-0.2.6.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-5sRVgyNkRUqLKXDwavVtV9
key:                  cborg-json-0.2.6.0-5sRVgyNkRUqLKXDwavVtV9
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  e3fe60a84e5f0b459b93416438e1726a
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-5sRVgyNkRUqLKXDwavVtV9
depends:
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf
    aeson-pretty-0.8.10-FF3kbqs1WvtKfkblP58Xcl base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb
    cborg-0.2.10.0-5l0qrlK9GoO9f01jDwZA5x
    scientific-0.3.8.0-DLDr5nembSsHeUMWxBP2Rn text-2.0.2
    unordered-containers-0.2.20-BdnqkwZm9bx6ocoMK9HG74
    vector-0.13.2.0-B5pfN7kp2sVHpMWItbJQ58

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cborg-json-0.2.6.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-Bakv9TZ4BWTFWPmpeDEPt
key:                  cborg-json-0.2.6.0-Bakv9TZ4BWTFWPmpeDEPt
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  6b4b846d7863afbb3e72af1935d2cd2c
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-Bakv9TZ4BWTFWPmpeDEPt
depends:
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp
    aeson-pretty-0.8.10-8K6VAOlgEiI6kbxgmBEhWH base-4.17.2.1
    base64-bytestring-1.2.1.0-9yKKMU9vx4T3mbm91B7Hi9
    cborg-0.2.10.0-Ol0l2aO0w696FYxGVg3Qt
    scientific-0.3.8.0-hGLqISimekA59HuDEk96u text-2.0.2
    unordered-containers-0.2.20-5YE9FG6zPmjDjdA4DCPpEY
    vector-0.13.2.0-2If6MrCrP3g55Bnhb5dowG

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
